<?php
function custom_regions() {
  return array(
	'leaderboard' => t('leaderboard'),
	'header' => t('header'),
	'sidebar_right' => t('right sidebar'),
	'sidebar_left' => t('left sidebar'),
		'above_content' => t('above content'),
  'content' => t('content'),
  'footer' => t('footer')
  );
}

/**
 * Sets the body-tag class attribute.
 *
 * Adds 'sidebar-left', 'sidebar-right' or 'sidebars' classes as needed.
 */
function phptemplate_body_class($sidebar_left, $sidebar_right) {
  if ($sidebar_left != '' && $sidebar_right != '') {
    $class = 'sidebars';
  }
  else {
    if ($sidebar_left != '') {
      $class = 'sidebar-left';
    }
    if ($sidebar_right != '') {
      $class = 'sidebar-right';
    }
  }

  if (isset($class)) {
    print ' class="'. $class .'"';
  }
}

/**
 * Return a themed breadcrumb trail.
 *
 * @param $breadcrumb
 *   An array containing the breadcrumb links.
 * @return a string containing the breadcrumb output.
 */
function phptemplate_breadcrumb($breadcrumb) {
  if (!empty($breadcrumb)) {
	$output = '<div class="breadcrumb">';
	//print_r($breadcrumb);exit;
	foreach ($breadcrumb as $i => $crumb)
	{
		if ($i == count($breadcrumb) - 1)
		{
			$output .= "$crumb</div>";
		}
		else
			$output .= $crumb . ' › ';
	}
    return $output;
  }
}

/**
 * Allow themable wrapping of all comments.
 */
function phptemplate_comment_wrapper($content, $type = null) {
  static $node_type;
  if (isset($type)) $node_type = $type;

  if (!$content || $node_type == 'forum') {
    return '<div id="comments">'. $content . '</div>';
  }
  else {
    return '<div id="comments"><h2 class="comments">'. t('Comments') .'</h2>'. $content .'</div>';
  }
}

/*
 * priary tabs
 */
function custom_primary_local_tasks($exclusions = array()) {
  if ($exclusions == array()){
    return menu_primary_local_tasks();
  }
    
  $local_tasks = menu_get_local_tasks();
  $pid = menu_get_active_nontask_item();
  $output = '';

  if (count($local_tasks[$pid]['children'])) {
    foreach ($local_tasks[$pid]['children'] as $mid) {
      $this_menu = menu_get_item($mid);
      if(!in_array($this_menu['title'],$exclusions)){
        $output .= theme('menu_local_task', $mid, menu_in_active_trail($mid), TRUE);
      }
    }
  }

  return $output;
}
  

/*
 * secondary tabs
 */
function custom_secondary_local_tasks($exclusions = array()) {
  if ($exclusions == array()){
    return menu_secondary_local_tasks();
  }
  
  $local_tasks = menu_get_local_tasks();
  $pid = menu_get_active_nontask_item();
  $output = '';

  if (count($local_tasks[$pid]['children'])) {
    foreach ($local_tasks[$pid]['children'] as $mid) {
      if (menu_in_active_trail($mid) && count($local_tasks[$mid]['children']) > 1) {
        foreach ($local_tasks[$mid]['children'] as $cid) {
          $this_menu = menu_get_item($cid);
          if(!in_array($this_menu['title'],$exclusions)){
            $output .= theme('menu_local_task', $cid, menu_in_active_trail($cid), FALSE);
          }
        }
      }
    }
  }

  return $output;
}

/**
 * Override or insert PHPTemplate variables into the templates.
 */
function _phptemplate_variables($hook, $vars) {
  if ($hook == 'page') {
    
    if ($vars['node']->type == 'quiz' && !user_access('administer quiz')){
      // hide the tabs
      $vars['tabs'] = '';
    }
    
    if ($vars['node']->type == 'gift_certificate'){
      // alter node for access check
      if(!isset($_GET['KeepThis'])){
        $vars['content'] = '<p>' . t("I'm sorry, you must redeem this gift certificate, after you pass the quiz!") . '</p>';
      }
      else {
        $vars['content'] = $vars['node']->body;
      }
      //print_r($vars['node']);exit;
      
    }
    
    // use a special template for thickbox
    if(isset($_GET['KeepThis'])){
      $vars['template_file'] = 'page-thickbox';
    }
    
    if ($vars['node']->type == 'bio'){
      // add a heading to the bio q&a
      $vars['content'] = str_replace('<div class="field field-type-text field-field-corkage-fee','<h2 class="title">What I think...</h2><div class="field field-type-text field-field-last-favorite',$vars['content']);
    }
	
	  if (drupal_is_front_page())
  		$vars['template_file'] = 'page-homepage';
  	elseif (arg(0) == "home-new")
  		$vars['template_file'] = 'page-homepage-new';
  	//elseif (arg(0) == 'node' && (arg(1) == '232' || arg(1) == '233' || arg(1) == '234' || arg(1) == '235' || arg(1) == '236'))
  	//	$vars['template_file'] = 'page-category'; 
  	elseif (arg(0)=="taxonomy" && arg(1)=="term" && (arg(2)=="9" || arg(2)=="2" || arg(2)=="3" || arg(2)=="4" || arg(2)=="27"))	
  		$vars['template_file'] = 'page-category';
  	elseif (arg(0)=="event-calendar")
  		$vars['template_file'] = 'page-calendar';
			
  	if ($secondary = menu_secondary_local_tasks()) {  
  	  // on the user page...  
  	  if (arg(0)=='user'){
  	    $vars['tabs2'] = '';
  	    /*global $user;
  	    // if the current user is NOT an admin
  	    if(!((in_array('admin', $user->roles))||(in_array('superadmin', $user->roles)))){
  	      // build the secondary links excluding admin-only category
          $secondary = custom_secondary_local_tasks($exclusions = array('Admin Options'));
        }// end if not admin */
      }// end if user page 
  	  else {
  	    $output = "<ul class=\"tabs secondary clear\">\n". $secondary ."</ul>\n";
        $vars['tabs2'] = $output;
  	  }
    }

    // Hook into color.module
    if (module_exists('color')) {
      _color_page_alter($vars);
    }

	  if (drupal_get_title()) {
        $head_title = array(strip_tags(drupal_get_title()), variable_get('site_name', 'drupal'));
  	}
  	else {
  	  $head_title = array(variable_get('site_name', 'drupal'));
  	  if (variable_get('site_slogan', ''))
  	  	$head_title[] = variable_get('site_slogan', '');
      }
  	$vars['head_title'] = implode(' - ', $head_title);
    
    // Page Title Module additions
    if (module_exists('page_title')) {
      $vars['head_title'] = page_title_page_get_title();
    }
  }
  else if ($hook == 'node'){
    $node = $vars['node']; // nice shorthand
    $vars['drupal_path'] = drupal_get_path_alias('node/'.$node->nid);
    
    if ($node->type == 'listing'){
      if ($vars['teaser'] == true){
        $url = content_format('field_website', $node->field_website[0], 'default', $node);
        $vars['content'] .= '<p>'.$url.'</p>';
        // make sure every teaser has a more link
        if ($node->links == array()){
          $node->links = array(
            'node_read_more' => Array(
              'title' => 'Read more',
              'href' => 'node/'.$node->nid,
              'attributes' => Array('title' => 'Read the rest of this posting.'),
            ),
          );
          $vars['links'] = theme('links', $node->links, $attributes = array('class' => 'links inline'));
        }
      }
    }
  }
  
  // for TAXONOMY TITLE
  if (arg(0) == 'taxonomy' && arg(1) == 'term' && is_numeric(arg(2)) && arg(2) > 0){
    // taxonomy term page - check for custom page title
    $title = _taxonomy_title_get_title(arg(2));
    if ($title != ''){
      // sets the meta title
      drupal_set_title($title);
      // assures the heading is also set
      $vars['title'] = $title;
    }
  }
  
  return $vars;
}

/**
 * Returns the rendered local tasks. The default implementation renders
 * them as tabs.
 *
 * @ingroup themeable
 */
function phptemplate_menu_local_tasks() {
  $output = '';

  if ($primary = menu_primary_local_tasks()) {
    if (arg(0) == 'user'){
      $primary = theme('primary_local_tasks', array('Track page visits', 'Biography', 'Personal files'));
    }
    $output .= "<ul class=\"tabs primary\">\n". $primary ."</ul>\n";
  }

  return $output;
}

function phptemplate_primary_links($links, $attributes = array('class' => 'links')) {
  $output = '';

  if (count($links) > 0) {
    $output = '<ul'. drupal_attributes($attributes) .'>';

    $num_links = count($links);
    $i = 1;

    foreach ($links as $key => $link) {
      $class = '';

      // Automatically add a class to each link and also to each LI
      if (isset($link['attributes']) && isset($link['attributes']['class'])) {
        $link['attributes']['class'] .= ' ' . $key;
        $class = $key;
      }
      else {
        $link['attributes']['class'] = $key;
        $class = $key;
      }

      // Add first and last classes to the list of links to help out themers.
      $extra_class = '';
      if ($i == 1) {
        $extra_class .= 'first ';
      }
      if ($i == $num_links) {
        $extra_class .= 'last ';
      }
      $output .= '<li class="'. $extra_class . $class .'">';

      // Is the title HTML?
      $html = isset($link['html']) && $link['html'];

      // Initialize fragment and query variables.
      $link['query'] = isset($link['query']) ? $link['query'] : NULL;
      $link['fragment'] = isset($link['fragment']) ? $link['fragment'] : NULL;

      if (isset($link['href'])) {
        $output .= l($link['title'], $link['href'], $link['attributes'], $link['query'], $link['fragment'], FALSE, $html);
      }
      else if ($link['title']) {
        //Some links are actually not links, but we wrap these in <span> for adding title and class attributes
        if (!$html) {
          $link['title'] = check_plain($link['title']);
        }
        $output .= '<span'. drupal_attributes($link['attributes']) .'>'. $link['title'] .'</span>';
      }

      $i++;
      $output .= "</li>\n";

      if ($i < $num_links + 1)
        $output .= '<li class="divider"></li>';
    }

    $output .= '</ul>';
  }

  return $output;
	
}

function phptemplate_panels_twocol_stacked($id, $content) {
  if ($id) {
    $idstr = " id='$id'";
  }

  $directory = base_path() . path_to_theme();

  if (drupal_is_front_page()) {
		$output = <<<EOT
<div class="panel-2col-stacked" $idstr>
  <div class="panel-col-top">
    <div>$content[top]</div>
  </div>
  <span class="clear"></span>
  <div class="panel-col-first">
  <div style="background-image: url('$directory/images/stockphotos/hp_featurebox_bg.jpg'); background-position: 1px bottom; background-repeat: no-repeat"><div id="xsnazzy"><b class="xtop"><b class="xb1"></b><b class="xb2"></b><b class="xb3"></b><b class="xb4"></b></b><div class="xboxcontent"><div class="teaser">$content[left]</div><span class="clear"></span>
		</div><b class="xbottom"><b class="xb4"></b><b class="xb3"></b><b class="xb2"></b><b class="xb1"></b></b></div></div>
  </div>

  <div class="panel-col-last">
    <div>$content[right]</div>
  </div>
  <div class="panel-col-bottom">
    <div>$content[bottom]</div>
  </div>
</div>
<br class="panel-clearer" />
EOT;
  } else {
	$output = <<<EOT
	<div class="panel-2col-stacked" $idstr>
	  <div class="panel-col-top">
	    <div>$content[top]</div>
	  </div>
	  <span class="clear"></span>
	  <div style="border-top: 1px solid #bad09d;">
			
					<div class="panel-col-first" style="border-right: 1px solid #bad09d;">
						<div>$content[left]</div>
					</div>
				
					<div class="panel-col-last">
						<div>$content[right]</div>
						<p align="right" style="padding: 10px"><span class="txt_14">&raquo;</span> <a href="our-contributors">Meet our Contributors</a></p>
					</div>

		</div>
		<span class="clear"></span>

	  <div class="panel-col-bottom">
	    <div>$content[bottom]</div>
	  </div>
	</div>
	<br class="panel-clearer" />
EOT;
  }

  return $output;
}

function phptemplate_realname($object, $link = TRUE) {
  if (!($object->profile_first_name || $object->profile_last_name)) {
    if ($object->uid && function_exists('profile_load_profile')) {
      profile_load_profile($object);
    }
  }

  if ($object->profile_first_name || $object->profile_last_name) {
    $name = $object->profile_first_name . ' ' . $object->profile_last_name;

    if ( $link && user_access('access user profiles')) {
      return 'By ' . l($name, 'user/'. $object->uid, array('title' => t('View user profile.')));
    }
    else {
      return 'By ' . check_plain($name);
    }
  }

  // Profile field not set, default to standard behaviour

  if ($object->uid && $object->name) {
    // Shorten the name when it is too long or it will break many tables.
    if (drupal_strlen($object->name) > 20) {
      $name = drupal_substr($object->name, 0, 15) .'...';
    }
    else {
      $name = $object->name;
    }

    if ( $link && user_access('access user profiles')) {
      $output = 'By ' . l($name, 'user/'. $object->uid, array('title' => t('View user profile.')));
    }
    else {
      $output = 'By ' . check_plain($name);
    }
  }
  else if ($object->name) {
    // Sometimes modules display content composed by people who are
    // not registered members of the site (e.g. mailing list or news
    // aggregator modules). This clause enables modules to display
    // the true author of the content.
    if ($object->homepage) {
      $output = l($object->name, $object->homepage);
    }
    else {
      $output = check_plain($object->name);
    }

    $output .= ' ('. t('not verified') .')';
  }
  else {
    $output = ''; //variable_get('anonymous', 'Anonymous');
  }

  return $output;
}

/**
* Catch the theme_profile_profile function, and redirect through the template api
*/
function phptemplate_user_profile($user, $fields = array()) {
  // Pass to phptemplate, including translating the parameters to an associative array. The element names are the names that the variables
  // will be assigned within your template.
  // potential need for other code to extract field info 
  return _phptemplate_callback('user_profile', array('account' => $user, 'fields' => $fields));
}

/**
* Display the nodes of a view as a table.
* see theme_views_view_list for a definition of $type
*/
function phptemplate_views_view_table($view, $nodes, $type) {
  $fields = _views_get_fields();

  foreach ($nodes as $node) {
    $row = array();
    foreach ($view->field as $field) {
      $cell['data'] = views_theme_field('views_handle_field', $field['queryname'], $fields, $field, $node, $view);
      $cell['class'] = "view-field view-field-$field[queryname]";
      $row[] = $cell;
    }
    $rows[] = $row;
  }
  return theme('table', $view->table_header, $rows);
}

//grid view customization

function phptemplate_views_bonus_view_grid($view, $nodes, $type) {
  drupal_add_css(drupal_get_path('module', 'views_bonus') .'/views_bonus.css');
  $fields = _views_get_fields();
  $content = '<table class="view-grid view-grid-' . $view->name . '">';
 //$content.= "<tr><td colspan='4'><br /></td></tr>";
  $count = 0;
  $total = count($nodes);
  foreach ($nodes as $node) {
    $item = '';
    if ($count % 3 == 0) { 
      $content .= '<tr>'; 
    }

    foreach ($view->field as $field) {
      if ($fields[$field['id']]['visible'] !== FALSE) {
        if ($field['label']) {
          $item .= "<span class='view-label view-label-$field[queryname]'>" . $field['label'] . "</span>";
        }
        $item .= views_theme_field('views_handle_field', $field['queryname'], $fields, $field, $node, $view);
		  if ($field['queryname'] == 'profile_first_name_value'){
		  	$item.=" ";
		  }
      }
    }
    $content .= "<td class='view-grid-item' width='25%' valign='bottom' align='center'>$item</td>\n"; 

    $count++;
    if ($count % 3 == 0 || $count == $total) {
      $content .= '</tr>';
    }
  }
  $content .= '</table>';
  
  if ($content) {
    return $content;
  }
}

//content splitter function
function _contentsplitter($incontent, $delimiter, $headlength)
{
  $outcontent = array();
 
  $tmp = explode($delimiter, $incontent, $headlength + 1);
 
  for ($i = 0; $i < $headlength; $i++) {
    $outcontent[0] .= $tmp[$i] . $delimiter;
  }
 
  $outcontent[1] = $tmp[$headlength];
 
  return $outcontent;
}

/* Quiz view customization */

/**
 * Theme a progress indicator for use during a quiz
 * 
 * @param $question_number
 *   The position of the current question in the sessions' array
 * @param $num_of_question
 *   The number of questions for this quiz as returned by quiz_get_number_of_questions()
 * @return
 *   Themed html
 */ /*
function phptemplate_quiz_progress($question_number, $num_of_question) {
  
  // Determine the percentage finished (not used but left for other implementations)
  //$progress = ($question_number*100)/$num_of_question;
  
  // Get the current question # by adding one
  $current_question = $question_number + 1;
  
  // return html
  $output = '';
  $output .= '<div id="quiz_progress">';
  $output .= t('Question %x of %y', array('%x' => $current_question, '%y' => $num_of_question));
  $output .= '</div><br />'."\n";
  return $output;

}
*/

/**
 * Theme a question page
 * 
 * @param $quiz
 *   The quiz node object
 * @param $question_node
 *   The question node
 * @return
 *   Themed html
 */ /*
function phptemplate_quiz_take_question($quiz, $question_node) {

  //Calculation for quiz progress bar 		  
  $number_of_questions = quiz_get_number_of_questions($quiz->nid);
  $question_number = $number_of_questions - count($_SESSION['quiz_'. $quiz->nid]['quiz_questions']);

  // Set the title here in case themers want to do something different
  drupal_set_title(check_plain($quiz->title)); 

  // Return the elements of the page
  $output = '';
  $output .= theme('quiz_progress', $question_number, $number_of_questions);         
  $output .= module_invoke($question_node->type, 'render_question', $question_node);
  return $output;
}
*/
/**
 * Pass the correct mark to the theme so that theme authors can use an image
 * 
 * TODO: A default image might be better here.
 */ /*
function phptemplate_quiz_score_correct() {
  return theme('image', drupal_get_path('module', 'quiz') .'/images/correct.gif', t('correct'));
}
*/

/**
 * Pass the incorrect mark to the theme so that theme authors can use an image
 *
 * TODO: A default image might be better here.
 */ /*
function phptemplate_quiz_score_incorrect() {
  return theme('image', drupal_get_path('module', 'quiz') .'/images/incorrect.gif', t('incorrect'));
}
*/
function phptemplate_gmap_views_marker_label($view, $fields, $entry) {
  $marker_label = '';
  
  foreach ($view->field as $field) {
    if ($field['queryname'] != 'location_latitude' && $field['queryname'] != 'location_longitude')
	  $marker_label .= '<div class="'. $field['field'] .'">'. views_theme_field('views_handle_field', $field['queryname'], $fields, $field, $entry, $view) .'</div>';
  }
  
  return $marker_label;
}

/**
 * Theme function for the multichoice form
 */ /*
function phptemplate_multichoice_render_question_form($form) {
  $output = '';
  $output .= drupal_render($form) .'</div>';
  $output .= '<br class="clear"/>';

  $block = module_invoke('block', 'block', 'view', 6);
  $output .= theme_block($block);

  return $output;
}
*/
/**
 * Theme the summary page after the quiz has been completed
 * 
 * @param $quiz
 *   The quiz node object
 * @param $questions
 *   The questions array as defined by _quiz_get_answers
 * @param $score
 *   Array of score information as returned by quiz_calculate_score()
 * @param $summary
 *   Filtered text of the summary
 * @return
 *   Themed html
 */ /*
function phptemplate_quiz_take_summary($quiz, $questions, $score, $summary) {

  // Set the title here so themers can adjust
  drupal_set_title(check_plain($quiz->title));

  // Display overall result
  $output = '';
  $output .= '<div id="quiz_score_possible">'. t('You got %num_correct of %question_count correct.', array('%num_correct' => $score['num_correct'], '%question_count' => $score['question_count'])) .'</div>'."\n";
  $output .= '<div id="quiz_score_percent">'. t('Your score: @score%', array('@score' => $score['percentage_score'])) .'</div><br />'."\n";
 
  if ($score['num_correct'] == 10)
  	$quip = 'You must be a wine pro right?';
  elseif ($score['num_correct'] == 9)
  	$quip .= 'Certifiable Wine Enthusiast';
  elseif ($score['num_correct'] == 8)
  	$quip .= 'Casual Drinker of Great Wine';
  elseif ($score['num_correct'] == 7)
  	$quip .= 'Ask your waiter more questions';
  elseif ($score['num_correct'] == 6)
  	$quip .= 'Have you been drinking wine from a box?';
  else
   	$quip .= 'Were you even trying? Take the quiz one more time!';
  $output .= '<div id="quiz_score_quip">'. $quip .'</div><br />'."\n";

  $output .= '<div id="mywines_ad" style="padding: 10px; border: 1px solid #bad09d;">
	<strong>Save $10 on the MyWinesDirect Intro Tasting Pack</strong><br /><br />
	As a thank you for taking the quiz, IntoWine has partnered with <a href="http://www.mywinesdirect.com/index.cfm?fuseaction=itemdetail&item_id_int=10979&category_id_int=14315&promo=intowine" target="_blank">MyWinesDirect</a> to offer you an exclusive discount:
<br /><br />
<strong style="color: #860037;">Save $10 on the MyWinesDirect Intro Tasting Pack – 4 reds and 2 whites for only $69.95 (regularly $79.95), and there are no shipping charges.</strong>
<br /><br />
Use the coupon code \'<strong>intowine</strong>\' at checkout to receive the discount.<br /><br /><a href="http://www.mywinesdirect.com/index.cfm?fuseaction=itemdetail&item_id_int=10979&category_id_int=14315&promo=intowine" target="_blank">Click here to receive your discount &raquo;</a></div><br />'."\n";
 	
   	
  $output .= '<div id="quiz_summary">'. $summary .'</div><br />'."\n";
  
  // Get the feedback for all questions
  $output .= theme('quiz_feedback', $questions, FALSE, TRUE);
  
  $output .= '<br class="clear"/>';
  $output .= _adsense_process_tags('<div class="adsense">[adsense:468x60:1:1]</div>');

  return $output;

}
*/

function phptemplate_poll_results($title, $results, $votes, $links, $block, $nid, $vote) {
  if ($block) {
    $output .= '<div class="poll">';
    $output .= '<div class="title">'. $title .'</div>';
    $output .= $results;
    //$output .= '<div class="total">'. t('Total votes: %votes', array('%votes' => $votes)) .'</div>';
    $output .= '</div>';
    $output .= '<div class="links">'. theme('links', $links) .'</div>';
  }
  else {
    $output .= '<div class="poll">';
    $output .= $results;
    $output .= '<div class="total">'. t('Total votes: %votes', array('%votes' => $votes)) .'</div>';
    if (isset($vote) && $vote > -1 && user_access('cancel own vote')) {
      $output .= drupal_get_form('poll_cancel_form', $nid);
    }
    $output .= '</div>';
  }

  return $output;
}

/**
 * views template to output a view.
 * This code was generated by the views theming wizard
 * Date: Fri, 09/28/2007 - 06:30
 * View: wine_tasting_notes
 *
 * This function goes in your template.php file
 */
function phptemplate_views_view_list_wine_tasting_notes($view, $nodes, $type) {
  $fields = _views_get_fields();

  $taken = array();

  // Set up the fields in nicely named chunks.
  foreach ($view->field as $id => $field) {
    $field_name = $field['field'];
    if (isset($taken[$field_name])) {
      $field_name = $field['queryname'];
    }
    $taken[$field_name] = true;
    $field_names[$id] = $field_name;
  }

  // Set up some variables that won't change.
  $base_vars = array(
    'view' => $view,
    'view_type' => $type,
  );

  foreach ($nodes as $i => $node) {
    $vars = $base_vars;
    $vars['node'] = $node;
    $vars['count'] = $i;
    $vars['stripe'] = $i % 2 ? 'even' : 'odd';
    foreach ($view->field as $id => $field) {
      $name = $field_names[$id];
      $vars[$name] = views_theme_field('views_handle_field', $field['queryname'], $fields, $field, $node, $view);
      if (isset($field['label'])) {
        $vars[$name . '_label'] = $field['label'];
      }
    }
    $items[] = _phptemplate_callback('views-list-wine_tasting_notes', $vars);
  }
  if ($items) {
    return tasting_notes_item_list($items);
  }
}

function tasting_notes_item_list($items = array(), $title = NULL, $type = 'ul', $attributes = NULL) {
  $output = '<div class="item-list">';
  if (isset($title)) {
    $output .= '<h3>'. $title .'</h3>';
  }

  if (!empty($items)) {
    $output .= "<$type" . drupal_attributes($attributes) . '>';
    foreach ($items as $item) {
      $attributes = array();
      $children = array();
      if (is_array($item)) {
        foreach ($item as $key => $value) {
          if ($key == 'data') {
            $data = $value;
          }
          elseif ($key == 'children') {
            $children = $value;
          }
          else {
            $attributes[$key] = $value;
          }
        }
      }
      else {
        $data = $item;
      }
      if (count($children) > 0) {
        $data .= theme_item_list($children, NULL, $type, $attributes); // Render nested list
      }
      $output .= '<li' . drupal_attributes($attributes) . '>'. $data .'</li>';
    }
    $output .= "</$type>";
  }
  $output .= '</div>';
  return $output;
}

function phptemplate_tasting_note_node_form($form) {
  
  $wineName = explode('[', $form['field_wine_tasted'][0]['node_name']['#default_value']);
  $wineName = trim($wineName[0]);

  if ($wineName) {
    $form['field_wine_tasted'][0]['node_name']['#type'] = 'hidden';
    $form['wine_tasted'] = array(
    '#value' => "<strong>Wine Tasted:</strong>  $wineName" ,
    '#weight' => -5 ,
  );
  }
 
  $output = "\n<div class=\"node-form\">\n";

  
  // Admin form fields and submit buttons must be rendered first, because
  // they need to go to the bottom of the form, and so should not be part of
  // the catch-all call to drupal_render().
  $admin = '';
  if (isset($form['author'])) {
    $admin .= "    <div class=\"authored\">\n";
    $admin .= drupal_render($form['author']);
    $admin .= "    </div>\n";
  }
  if (isset($form['options'])) {
    $admin .= "    <div class=\"options\">\n";
    $admin .= drupal_render($form['options']);
    $admin .= "    </div>\n";
  }
  $buttons = drupal_render($form['preview']);
  $buttons .= drupal_render($form['submit']);
  $buttons .= isset($form['delete']) ? drupal_render($form['delete']) : '';

  // Everything else gets rendered here, and is displayed before the admin form
  // field and the submit buttons.
  $output .= "  <div class=\"standard\">\n";
  $output .= drupal_render($form);
  $output .= "  </div>\n";

  if (!empty($admin)) {
    $output .= "  <div class=\"admin\">\n";
    $output .= $admin;
    $output .= "  </div>\n";
  }
  $output .= $buttons;
  $output .= "</div>\n";

  return $output;
}

function get_ad_group_tid($terms) {
  if ($terms) {
    foreach ($terms as $term)
      if ($term->vid == 4)
        return $term->tid;
  }
  
  return null;
}

function phptemplate_views_view_table_my_tasting_notes($view, $nodes, $type) {
  $fields = _views_get_fields();

  foreach ($nodes as $node) {
    $row = array();
    foreach ($view->field as $field) {
      if ($fields[$field['id']]['visible'] !== FALSE) {
        $cell['data'] = views_theme_field('views_handle_field', $field['queryname'], $fields, $field, $node, $view);
        $cell['class'] = "view-field ". views_css_safe('view-field-'. $field['queryname']);
        $row[] = $cell;
      }
    }
    $rows[] = $row;
  }
  return theme('table', $view->table_header, $rows, array('width' => '100%'));
}

function phptemplate_views_view_table_my_wine_cellar($view, $nodes, $type) {
  $fields = _views_get_fields();

  foreach ($nodes as $node) {
    $row = array();
    foreach ($view->field as $field) {
      if ($fields[$field['id']]['visible'] !== FALSE) {
        $cell['data'] = views_theme_field('views_handle_field', $field['queryname'], $fields, $field, $node, $view);
        $cell['class'] = "view-field ". views_css_safe('view-field-'. $field['queryname']);
        $row[] = $cell;
      }
    }
    $rows[] = $row;
  }
  return theme('table', $view->table_header, $rows, array('width' => '100%'));
}

/**
 * views template to output a view.
 * This code was generated by the views theming wizard
 * Date: Thu, 11/01/2007 - 21:41
 * View: in_content_ad
 *
 * This function goes in your template.php file
 */
function phptemplate_views_view_list_in_content_ad($view, $nodes, $type) {
  $fields = _views_get_fields();

  $taken = array();

  // Set up the fields in nicely named chunks.
  foreach ($view->field as $id => $field) {
    $field_name = $field['field'];
    if (isset($taken[$field_name])) {
      $field_name = $field['queryname'];
    }
    $taken[$field_name] = true;
    $field_names[$id] = $field_name;
  }

  // Set up some variables that won't change.
  $base_vars = array(
    'view' => $view,
    'view_type' => $type,
  );

  foreach ($nodes as $i => $node) {
    $vars = $base_vars;
    $vars['node'] = $node;
    $vars['count'] = $i;
    $vars['stripe'] = $i % 2 ? 'even' : 'odd';
    foreach ($view->field as $id => $field) {
      $name = $field_names[$id];
      $vars[$name] = views_theme_field('views_handle_field', $field['queryname'], $fields, $field, $node, $view);
      if (isset($field['label'])) {
        $vars[$name . '_label'] = $field['label'];
      }
    }
    $items[] = _phptemplate_callback('views-list-in_content_ad', $vars);
  }
  if ($items) {
    return in_content_ad_item_list($items);
  }
}

function in_content_ad_item_list($items = array(), $title = NULL, $type = 'ul', $attributes = NULL) {
  $output = '<div class="item-list">';
  if (isset($title)) {
    $output .= '<h3>'. $title .'</h3>';
  }

  if (!empty($items)) {
    foreach ($items as $item) {
      $attributes = array();
      $children = array();
      if (is_array($item)) {
        foreach ($item as $key => $value) {
          if ($key == 'data') {
            $data = $value;
          }
          elseif ($key == 'children') {
            $children = $value;
          }
          else {
            $attributes[$key] = $value;
          }
        }
      }
      else {
        $data = $item;
      }
      if (count($children) > 0) {
        $data .= theme_item_list($children, NULL, $type, $attributes); // Render nested list
      }
      $output .= $data;
    }
  }
  $output .= '</div>';
  return $output;
}

function user_owns_wine($nid, $uid) {
	$result = db_query("SELECT field_cellar_owners_uid FROM content_field_cellar_owners WHERE nid = $nid");
	
	while ($row = db_fetch_array($result)) {
		if ($row['field_cellar_owners_uid'] == $uid)
			return true;
	}
	
	return false;
}

/* for all CCK node/add/type form theming */
function phptemplate_node_form($form) {
  if(file_exists(path_to_theme().'/'.$form['type']['#value'].'-form.tpl.php')) {
    return _phptemplate_callback($form['type']['#value'].'-form', array('user' => $user, 'form' => $form));
  }
}

/* for all form elements theming 
function phptemplate_form_element($element, $value) {
	if (module_exists('cck_css')){
		//$output = print_r($element);
		$output = '<div class="form-item '.substr($element['#id'],11).'">'."\n";
		$required = !empty($element['#required']) ? '<span class="form-required" title="'. t('This field is required.') .'">*</span>' : '';
	
		if (!empty($element['#title'])) {
			$title = $element['#title'];
			if (!empty($element['#id'])) {
				$output .= ' <label for="'. $element['#id'] .'">'. t('!title: !required', array('!title' => filter_xss_admin($title), '!required' => $required)) ."</label>\n";
			}
			else {
				$output .= ' <label>'. t('!title: !required', array('!title' => filter_xss_admin($title), '!required' => $required)) ."</label>\n";
			}
		}
	
		$output .= " $value\n";
	
		if (!empty($element['#description'])) {
			$output .= ' <div class="description">'. $element['#description'] ."</div>\n";
		}
	
		$output .= "</div>\n";
	
		return $output;
	}
}
*/

/**
 * views template to output a view.
 * This code was generated by the views theming wizard
 * Date: Sun, 05/04/2008 - 23:16
 * View: users_featured
 *
 * This function goes in your template.php file
 */
function phptemplate_views_view_list_users_featured($view, $nodes, $type) {
  $fields = _views_get_fields();

  $taken = array();

  // Set up the fields in nicely named chunks.
  foreach ($view->field as $id => $field) {
    $field_name = $field['field'];
    if (isset($taken[$field_name])) {
      $field_name = $field['queryname'];
    }
    $taken[$field_name] = true;
    $field_names[$id] = $field_name;
  }

  // Set up some variables that won't change.
  $base_vars = array(
    'view' => $view,
    'view_type' => $type,
  );

  foreach ($nodes as $i => $node) {
    $vars = $base_vars;
    $vars['node'] = $node;
    $vars['count'] = $i;
    $vars['stripe'] = $i % 2 ? 'even' : 'odd';
    foreach ($view->field as $id => $field) {
      $name = $field_names[$id];
      $value = views_theme_field('views_handle_field', $field['queryname'], $fields, $field, $node, $view);
      $vars[$name] = str_replace('<!--paging_filter-->','',$value);
      //add labels into data var
      if (isset($field['label'])) {
        $vars[$name . '_label'] = $field['label'];
        // remove first p from $vars[$name]
        $firstp = '';
        if (substr($vars[$name],0,3)=='<p>'){
          // if p starts, separate
          $nofirstp = substr($vars[$name],3);
          $firstp = '<p>';
          // insert label and add it all back together
          $vars[$name] = $firstp.'<div class="view-label">'.$vars[$name . '_label'].'</div> '.$nofirstp;
          $vars[$name . '_label']= null;
        }
      }
    }
    $items[] = _phptemplate_callback('views-list-users_featured', $vars);
  }
  if ($items) {
    return theme('item_list', $items);
  }
}

function custom_print_format_link() {
  return array('text' => t('Printer-friendly'),
               'html' => FALSE,
               'attributes' => print_fill_attributes());
}


function custom_filter_tips($tips, $long = FALSE, $extra = '') {
  if (arg(0)=='user'&&arg(2)=='bio'){
    return;
  } else {
    $output = '';

    $multiple = count($tips) > 1;
    if ($multiple) {
      $output = t('input formats') .':';
    }
    if (count($tips)) {
      if ($multiple) {
        $output .= '<ul>';
      }
      foreach ($tips as $name => $tiplist) {
        if ($multiple) {
          $output .= '<li>';
          $output .= '<strong>'. $name .'</strong>:<br />';
        }
        $tips = '';
        foreach ($tiplist as $tip) {
          $tips .= '<li'. ($long ? ' id="filter-'. str_replace("/", "-", $tip['id']) .'">' : '>') . $tip['tip'] . '</li>';
        }
        if ($tips) {
          $output .= "<ul class=\"tips\">$tips</ul>";
        }
        if ($multiple) {
          $output .= '</li>';
        }
      }
      if ($multiple) {
        $output .= '</ul>';
      }
    }
    return $output;
  }
}

/**
 * views template to output a view.
 * This code was generated by the views theming wizard
 * Date: Sat, 05/24/2008 - 12:20
 * View: users_featured_bl
 *
 * This function goes in your template.php file
 */
function phptemplate_views_view_list_users_featured_bl($view, $nodes, $type) {
  $fields = _views_get_fields();

  $taken = array();

  // Set up the fields in nicely named chunks.
  foreach ($view->field as $id => $field) {
    $field_name = $field['field'];
    if (isset($taken[$field_name])) {
      $field_name = $field['queryname'];
    }
    $taken[$field_name] = true;
    $field_names[$id] = $field_name;
  }

  // Set up some variables that won't change.
  $base_vars = array(
    'view' => $view,
    'view_type' => $type,
  );

  foreach ($nodes as $i => $node) {
    $vars = $base_vars;
    $vars['node'] = $node;
    $vars['count'] = $i;
    $vars['stripe'] = $i % 2 ? 'even' : 'odd';
    foreach ($view->field as $id => $field) {
      $name = $field_names[$id];
      $value = views_theme_field('views_handle_field', $field['queryname'], $fields, $field, $node, $view);
      $vars[$name] = str_replace('<!--paging_filter-->','',$value);
      //add labels into data var
      if (isset($field['label'])) {
        $vars[$name . '_label'] = $field['label'];
        // remove first p from $vars[$name]
        $firstp = '';
        if (substr($vars[$name],0,3)=='<p>'){
          // if p starts, separate
          $nofirstp = substr($vars[$name],3);
          $firstp = '<p>';
          // insert label and add it all back together
          $vars[$name] = $firstp.'<div class="view-label">'.$vars[$name . '_label'].'</div> '.$nofirstp;
          $vars[$name . '_label']= null;
        }
      }
    }
    $items[] = _phptemplate_callback('views-list-users_featured_bl', $vars);
  }
  if ($items) {
    return theme('item_list', $items);
  }
}

/**
 * Theme function makes grid-view views only 2 columns wide
 */
function custom_views_bonus_view_grid_users_featured_bl($view, $nodes, $type) {
  drupal_add_css(drupal_get_path('module', 'views_bonus_grid') .'/views_bonus.css');
  $fields = _views_get_fields();
  $content = '<table class="view-grid view-grid-' . $view->name . '">';
  
  // set default count. - jen changed this file
  $cols = $view->gridcount ? $view->gridcount : 2;

  $count = 0;
  $total = count($nodes);
  foreach ($nodes as $node) {
    $item = '';
    if ($count % $cols == 0) { 
      $content .= '<tr>'; 
    }

    foreach ($view->field as $field) {
      if ($fields[$field['id']]['visible'] !== FALSE) {
        if ($field['label']) {
          $item .= "<div class='view-label view-label-$field[queryname]'>" . $field['label'] . "</div>";
        }
        $item .= "<div class='view-field view-data-$field[queryname]'>" . views_theme_field('views_handle_field', $field['queryname'], $fields, $field, $node, $view) . "</div>";
      }
    }
    $content .= "<td class='view-grid-item'><div class='view-item view-item-$view->name'>$item</div></td>\n"; 

    $count++;
    if ($count % $cols == 0 || $count == $total) {
      $content .= '</tr>';
    }
  }
  $content .= '</table>';
  
  if ($content) {
    return $content;
  }
}

/**
 * Display the results of a view in a Google Map.
 */
function custom_views_view_gmap($view, $results) {
  // Fields are used to render the markers.
  $fields = _views_get_fields();
  
  // find the ids of the column we want to use
  $point_ids = _gmap_views_find_coords_ids($view);
  
  if (isset($view->gmap_macro) && $view->gmap_macro) {
    $thismap = array(
      '#map' => 'view_gmap',
      '#settings' => array_merge(gmap_defaults(),gmap_parse_macro($view->gmap_macro)),
    );
    $thismap['#settings']['behavior']['notype'] = 1;
    if ($thismap['#settings']['behavior']['views_autocenter']) {
      // If a winery

      // Find the first valid location.
      foreach ($results as $entry) {
        $location = _gmap_views_get_lat_long_from_ids($entry, $point_ids);
        if (($location['lat']) && ($location['lon'])) {
          // Set default location for map
          $thismap['#settings']['latitude'] = $location['lat'];
          $thismap['#settings']['longitude'] = $location['lon'];
          // Break loop because we have what we want.
          break;
        }
      }
    }

  }
  else {
    $thismap = array(
      '#map' => 'view_gmap',
      '#settings' => gmap_defaults(),
    );
  }

  $fatmarkers = (isset($thismap['#settings']['behavior']['fatmarkers']) && $thismap['#settings']['behavior']['fatmarkers']);

  $markers = array();

  if ($fatmarkers) {
    $thismap['#settings']['viewfields'] = $view->field;
    $datafields = array();
    foreach ($view->field as $field) {
      if ($fields[$field['id']]['visible'] !== FALSE) {
        $datafields[] = $field['queryname'];
      }
    }
  }

  foreach ($results as $entry) {
    // @@@
    $type = isset($entry->node_type) ? $entry->node_type : '';
    $location = _gmap_views_get_lat_long_from_ids($entry, $point_ids);
    
    if (($location['lat']) && ($location['lon'])) {
      if ($fatmarkers) {
        $data = array();
        foreach ($view->field as $field) {
          if ($fields[$field['id']]['visible'] !== FALSE) {
            $data[] = views_theme_field('views_handle_field', $field['queryname'], $fields, $field, $entry, $view);
          }
        }
        $themarker = array(
          'markername' => variable_get('gmap_node_marker_'.$type, ''),
          'latitude' => $location['lat'],
          'longitude' => $location['lon'],
          'view' => array_values($data),
        );
      }
      else {
        $marker_tabs = theme('gmap_views_marker_label', $view, $fields, $entry);

        $themarker = array(
          // @@@
          'markername' => variable_get('gmap_node_marker_'.$type, ''),
          'latitude' => $location['lat'],
          'longitude' => $location['lon']
        );
        // add themed infoWindow HTML to either 'tabs' or 'text' 
        if(is_array($marker_tabs)) {
            foreach($marker_tabs as $tabi => $tabvalue) {
                $marker_tabs[$tabi] = strtr($tabvalue, "'\n\r", '" ');
            }
            $themarker['tabs'] = $marker_tabs;
        } else {
            $themarker['text'] = strtr($marker_tabs,"'\n\r",'" ');
        }
      }

      $markers[] = $themarker;
    }
  }
  $thismap['#settings']['markers'] = $markers;
  $output .= theme('gmap',$thismap);
  return $output;
}

/**
 * Theme a marker label.
 */
function custom_gmap_views_marker_label($view, $fields, $entry){
  $marker_label = '';
  foreach ($view->field as $field) {
    // if this is a node page
    if (arg(0) == 'node' && is_numeric(arg(1)) && arg(1) > 0){
      // load the node
      $winery = node_load(arg(1));
      $isnode = true;
    } // end node 
      // if the map is on a winery page - remove info from the marker label
    if ($isnode && $winery->type == 'winery'){
      if ($field['field'] != 'longitude' && $field['field'] != 'latitude' && $field['field'] != 'address' ){
        $marker_label .= '<div class="'. $field['field'] .'">'. views_theme_field('views_handle_field', $field['queryname'], $fields, $field, $entry, $view) .'</div>';
      }
    } // end winery
    // otherwise use the default
    else {
      if ($field['field'] != 'longitude' && $field['field'] != 'latitude'){
        $marker_label .= '<div class="'. $field['field'] .'">'.  views_theme_field('views_handle_field', $field['queryname'], $fields, $field, $entry, $view) .'</div>'; 
      }
    }
  }//foreach

  return $marker_label;
}

function custom_location($location = array(), $hide = array()) {
    //print_r($location);exit;
  $hide = array('latitude','longitude','country','country_name');
  $variables = array('location' => $location, 'hide' => $hide);
  return _location_render('location', $variables);
}

/*
 * Override search page - page titles
 */
function custom_search_page($results, $type) {
  // Change the title to Top Search 
  //$top_search_path = base_path() . 'top-searches';
  $top_search_path = 'http://www.intowine.com/top-searches';
  $search_page_path = '/http:\/\/www.intowine.com\/search\/node\//';
  if (isset($_SERVER['HTTP_REFERER']) && ($_SERVER['HTTP_REFERER'] == $top_search_path || preg_match($search_page_path, $_SERVER['HTTP_REFERER']) )){
    drupal_set_title(arg(2) . " - Top Search ");
  }
  
  $output = '<dl class="search-results">';

  foreach ($results as $entry) {
    $output .= theme('search_item', $entry, $type);
  }
  $output .= '</dl>';
  $output .= theme('pager', NULL, 10, 0);

  return $output;
}

/*
 * Override quiz results page
 */
function custom_quiz_take_summary($quiz, $questions, $score, $summary) {
  // Set the title here so themers can adjust.
  drupal_set_title(check_plain($quiz->title));
  
  //print_r($quiz);exit;

  // Display overall result.
  $output = '';
  if ($score['percentage_score']) {
    $output .= '<div id="quiz_score_possible">'. t('You got %num_correct of %question_count correct.', array('%num_correct' => $score['num_correct'], '%question_count' => $score['question_count'])) .'</div>'."\n";
    $output .= '<div id="quiz_score_percent">'. t('Your score: %score%', array('%score' => $score['percentage_score'])) .'</div><br />'."\n";
  }
  
  if (trim($quiz->summary_pass) != '' && $quiz->pass_rate > 0 && $score['percentage_score'] >= $quiz->pass_rate) {
    $summary = check_markup($quiz->summary_pass, $quiz->format, FALSE);
    
    // action for winning is gift cert
    $action_link = '<div class="action-link">' . l('Claim your gift certificate', drupal_get_path_alias('node/' . $quiz->field_gift_certificate[0]['nid']), array('class'=>'thickbox'), 'KeepThis=true&TB_iframe=true&height=500&width=600') . '</div>';
  }
  else {
   $summary = check_markup($quiz->summary_default, $quiz->format, FALSE);
   // action for loosing is to try again
   $action_link =  '<div class="action-link">';
   $action_link .= 'Would you like to ' . l('Try Again', 'node/' . $quiz->nid . '/quiz/start') . '?';
   $action_link .= '</div>';
  }

  $output .= '<div id="quiz_summary">'. $summary . $action_link . '</div>'."\n";
  // Get the feedback for all questions.
  $output .= theme('quiz_feedback', $questions, ($quiz->pass_rate > 0), TRUE);
  return $output;
}

/**
 * Theme a question page
 */
function custom_quiz_take_question($quiz, $question_node) {

  //Calculation for quiz progress bar 		  
  $number_of_questions = quiz_get_number_of_questions($quiz->nid);
  $question_number = $number_of_questions - count($_SESSION['quiz_'. $quiz->nid]['quiz_questions']);

  // Set the title here in case themers want to do something different
  drupal_set_title(check_plain($quiz->title)); 

  // Return the elements of the page
  $output = '<h1 class="title">' . $quiz->title . '</h1>';
  $output .= theme('quiz_progress', $question_number, $number_of_questions);         
  $output .= module_invoke($question_node->type, 'render_question', $question_node);
  return $output;
}